import { transformError as sdkTransformError } from '@wix/sdk-runtime/transform-error';
import { renameKeysFromSDKRequestToRESTRequest, renameKeysFromRESTResponseToSDKResponse, } from '@wix/sdk-runtime/rename-all-nested-keys';
import * as ambassadorWixPremiumDomainsV2Availability from './premium-domains-v2-availability-domain-availability.http.js';
/**
 * Checks whether the given domain is available for purchase.
 *
 *
 * You can purchase the specified domain in case the returned
 * `availability.available` boolean is `true`. The domain is already taken
 * when `false` is returned.
 *
 * The `domain` field must include the TLD. For example, `my-new-domain.com`.
 *
 * > __Important:__ This call requires an account level API key and cannot be authenticated with the standard authorization header.
 * @param domain - Domain name. Must include the TLD. For example, `my-new-domain.com`. Only
 * alphanumeric characters, hyphens, and dots are supported.
 *
 * Min: 3 characters
 * Max: 63 characters
 * @public
 * @requiredField domain
 * @permissionId DOMAINS.PUBLIC_API_PERMISSION
 * @fqn com.wixpress.premium.domain.search.availability.v2.DomainAvailabilityService.CheckDomainAvailability
 */
export async function checkDomainAvailability(domain) {
    // @ts-ignore
    const { httpClient, sideEffects } = arguments[1];
    const payload = renameKeysFromSDKRequestToRESTRequest({ domain: domain });
    const reqOpts = ambassadorWixPremiumDomainsV2Availability.checkDomainAvailability(payload);
    sideEffects?.onSiteCall?.();
    try {
        const result = await httpClient.request(reqOpts);
        sideEffects?.onSuccess?.(result);
        return renameKeysFromRESTResponseToSDKResponse(result.data);
    }
    catch (err) {
        const transformedError = sdkTransformError(err, {
            spreadPathsToArguments: {},
            explicitPathsToArguments: { domain: '$[0]' },
            singleArgumentUnchanged: false,
        }, ['domain']);
        sideEffects?.onError?.(err);
        throw transformedError;
    }
}
//# sourceMappingURL=premium-domains-v2-availability-domain-availability.universal.js.map